﻿using Rhino;
using Rhino.Commands;
using Rhino.DocObjects;
using Rhino.Geometry;
using Rhino.Input;
using System.Linq;

namespace UnweldNgonMesh
{
    public class UnweldNgonMeshCommand : Command
    {
        public UnweldNgonMeshCommand()
        {
            Instance = this;
        }
        public static UnweldNgonMeshCommand Instance
        {
            get; private set;
        }
        public override string EnglishName => "UnweldNgonMesh";
        protected override Result RunCommand(RhinoDoc doc, RunMode mode)
        {
            var rc = RhinoGet.GetMultipleObjects("Select Mesh", false, ObjectType.Mesh, out var objRefs);
            if (rc != Result.Success) return rc;
            foreach (var objRef in objRefs)
            {
                var mesh = objRef.Mesh();
                var oMesh = new Mesh();
                oMesh.Append(mesh.GetNgonAndFacesEnumerable()
                    .Select(ngon => mesh.DuplicateMesh().Faces.ExtractFaces(ngon.FaceIndexList().Select(i => unchecked((int)i)))));
                oMesh.RebuildNormals();
                doc.Objects.AddMesh(oMesh);
            }
            return Result.Success;
        }
    }
}